@@ -5,7 +5,7 @@ import { QueryTypes } from 'sequelize';
 import { InvalidParameterError } from '@tamanu/shared/errors';
 import { ENCOUNTER_TYPES, NOTE_TYPES } from '@tamanu/constants';
 
-import { renameObjectKeys } from '@tamanu/shared/utils';
+import { renameObjectKeys } from '@tamanu/utils/renameObjectKeys';
 
 import { simpleGet, simplePut } from '@tamanu/shared/utils/crudHelpers';
 
@@ -51,7 +51,7 @@ triage.post(
     const triageRecord = await models.Triage.create({ ...body, departmentId, actorId: user.id });
 
     if (vitals) {
-      const getDefaultId = async type =>
+      const getDefaultId = async (type) =>
         models.SurveyResponseAnswer.getDefaultId(type, settings[facilityId]);
       const updatedBody = {
         locationId: vitals.locationId || (await getDefaultId('location')),
@@ -78,7 +78,7 @@ triage.post(
     const encounter = await models.Encounter.findOne({
       where: { id: triageRecord.encounterId },
     });
-    await encounter.addTriageScoreNote(triageRecord, Date.now(), user);
+    await encounter.addTriageScoreNote(triageRecord, user);
 
     res.send(triageRecord);
   }),
@@ -175,7 +175,7 @@ triage.get(
         },
       },
     );
-    const forResponse = result.map(x => renameObjectKeys(x.forResponse()));
+    const forResponse = result.map((x) => renameObjectKeys(x.forResponse()));
 
     res.send({
       data: forResponse,
