@@ -1,7 +1,7 @@
 import React from 'react';
 import { DataSection } from './DataSection';
 import { Col } from '../Layout';
-import { getDOBWithAge, getSex, getVillageName } from '../../patientAccessors';
+import { getDobWithAge, getSex, getVillageName } from '../../patientAccessors';
 import { useLanguageContext } from '../../pdf/languageContext';
 import { renderDataItems } from './renderDataItems';
 
@@ -9,7 +9,7 @@ const PATIENT_FIELDS = {
   leftCol: [
     { key: 'firstName', label: 'First name' },
     { key: 'lastName', label: 'Last name' },
-    { key: 'dateOfBirth', label: 'DOB', accessor: getDOBWithAge },
+    { key: 'dateOfBirth', label: 'DOB', accessor: getDobWithAge },
   ],
   rightCol: [
     { key: 'displayId', label: 'Patient ID' },
